# Generated by roxygen2: do not edit by hand

S3method(print,manureshed_hub)
export(CONUS_STATES)
export(KG_TO_TONS)
export(LBS_TO_KG)
export(LBS_TO_TONS)
export(MANURESHED_CRS)
export(P2O5_TO_P)
export(add_centroid_coordinates)
export(add_texas_huc8)
export(agri_classify_complete)
export(agri_classify_complete_custom)
export(agri_classify_nitrogen)
export(agri_classify_nitrogen_custom)
export(agri_classify_phosphorus)
export(agri_classify_phosphorus_custom)
export(agri_process_nugis)
export(batch_analysis_enhanced)
export(batch_analysis_parallel)
export(batch_analysis_years)
export(benchmark_analysis)
export(calculate_cropland_threshold)
export(calculate_transition_probabilities)
export(check_builtin_data)
export(citation_info)
export(clean_category_names)
export(clear_data_cache)
export(compare_analyses)
export(compare_regions)
export(compare_scenarios)
export(convert_load_units)
export(create_analysis_report)
export(create_classification_summary)
export(create_network_plot)
export(download_all_data)
export(download_cafo_data)
export(download_osf_data)
export(export_for_gis)
export(export_for_policy)
export(export_for_publication)
export(export_hub_results)
export(filter_by_state)
export(format_huc8)
export(get_cropland_threshold)
export(get_nutrient_colors)
export(get_region_definitions)
export(get_state_boundaries)
export(get_state_fips)
export(health_check)
export(integrate_complete)
export(integrate_wwtp_agricultural)
export(launch_dashboard)
export(list_available_years)
export(list_regions)
export(load_builtin_boundaries)
export(load_builtin_nugis)
export(load_builtin_wwtp)
export(load_user_wwtp)
export(map_agricultural_classification)
export(map_hub_sites)
export(map_wwtp_columns)
export(map_wwtp_influence)
export(map_wwtp_points)
export(plot_absolute_changes)
export(plot_before_after_comparison)
export(plot_impact_ratios)
export(quick_analysis)
export(quick_check)
export(quick_state_analysis)
export(run_builtin_analysis)
export(run_state_analysis)
export(save_analysis_summary)
export(save_centroid_data)
export(save_plot)
export(save_spatial_data)
export(save_transition_matrix)
export(score_hub_sites)
export(summarize_results)
export(test_osf_connection)
export(view_cheatsheet)
export(wwtp_aggregate_by_boundaries)
export(wwtp_classify_sources)
export(wwtp_clean_data)
export(wwtp_filter_positive_loads)
export(wwtp_process_complete)
export(wwtp_to_spatial)
importFrom(dplyr,across)
importFrom(dplyr,all_of)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,case_when)
importFrom(dplyr,desc)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,if_else)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,n_distinct)
importFrom(dplyr,right_join)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(dplyr,slice_max)
importFrom(dplyr,summarise)
importFrom(ggplot2,aes)
importFrom(ggplot2,coord_sf)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_sf)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggsave)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_fill_distiller)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_minimal)
importFrom(magrittr,"%>%")
importFrom(rlang,":=")
importFrom(rlang,sym)
importFrom(sf,sf_use_s2)
importFrom(sf,st_as_sf)
importFrom(sf,st_buffer)
importFrom(sf,st_centroid)
importFrom(sf,st_coordinates)
importFrom(sf,st_distance)
importFrom(sf,st_drop_geometry)
importFrom(sf,st_intersects)
importFrom(sf,st_join)
importFrom(sf,st_point_on_surface)
importFrom(sf,st_transform)
importFrom(sf,st_within)
importFrom(sf,st_write)
importFrom(stats,cor)
importFrom(stats,ecdf)
importFrom(stats,median)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,replace_na)
importFrom(utils,download.file)
importFrom(utils,head)
importFrom(utils,read.csv)
importFrom(utils,write.csv)
